"use strict";
/**
 * @fileoverview Story files should have a default export
 * @author Yann Braga
 */
const constants_1 = require("../utils/constants");
const ast_1 = require("../utils/ast");
const create_storybook_rule_1 = require("../utils/create-storybook-rule");
module.exports = (0, create_storybook_rule_1.createStorybookRule)({
    name: 'default-export',
    defaultOptions: [],
    meta: {
        type: 'problem',
        docs: {
            description: 'Story files should have a default export',
            categories: [constants_1.CategoryId.CSF, constants_1.CategoryId.RECOMMENDED],
            recommended: 'error',
        },
        messages: {
            shouldHaveDefaultExport: 'The file should have a default export.',
        },
        schema: [],
    },
    create(context) {
        // variables should be defined here
        //----------------------------------------------------------------------
        // Helpers
        //----------------------------------------------------------------------
        // any helper functions should go here or else delete this section
        //----------------------------------------------------------------------
        // Public
        //----------------------------------------------------------------------
        let hasDefaultExport = false;
        return {
            ExportDefaultSpecifier: function () {
                hasDefaultExport = true;
            },
            ExportDefaultDeclaration: function () {
                hasDefaultExport = true;
            },
            'Program:exit': function (node) {
                if (!hasDefaultExport) {
                    const firstNonImportStatement = node.body.find((n) => !(0, ast_1.isImportDeclaration)(n));
                    context.report({
                        node: firstNonImportStatement || node.body[0] || node,
                        messageId: 'shouldHaveDefaultExport',
                    });
                }
            },
        };
    },
});
